==> blancoBatchProcess-0.1.2-src.zip: blancoBatchProcess/blanco/main/blanco/batchprocess/task/valueobject/BlancoBatchProcessBatchProcessInput.java <==
/*
 * ̃\[XR[h blanco FrameworkɂĎĂ܂B
 * ̃NXblancoValueObjectɂ莩܂B
 */
package blanco.batchprocess.task.valueobject;

/**
 * ob`NX [BlancoBatchProcessBatchProcess]̓̓o[IuWFNgNXłB BlancoResourceBundleAntTaskłB
 */
public class BlancoBatchProcessBatchProcessInput {
    /**
     * tB[h [verbose]
     *
     * ڂ̌^ [java.lang.String]<br>
     * verbose[hœ삳邩ǂB
     */
    private String fVerbose;

    /**
     * tB[h [metadir]
     *
     * ڂ̌^ [java.lang.String]<br>
     * ^fBNgBxlst@C̊i[܂ xmlt@C̊i[w肵܂B
     */
    private String fMetadir;

    /**
     * tB[h [targetdir]
     *
     * ڂ̌^ [java.lang.String]<br>
     * o͐tH_w肵܂Bw̏ꍇɂ̓Jgblancop܂B
     */
    private String fTargetdir;

    /**
     * tB[h [tmpdir]
     *
     * ڂ̌^ [java.lang.String]<br>
     * e|fBNgw肵܂Bw̏ꍇɂ̓Jgtmpp܂B
     */
    private String fTmpdir;

    /**
     * tB[h [targetlang]
     *
     * ڂ̌^ [java.lang.String]<br>
     * ^[QbgƂȂvO~OꏈnBjava, cs, jsI\
     */
    private String fTargetlang;

    /**
     * tB[h [runtimepackage]
     *
     * ڂ̌^ [java.lang.String]<br>
     * ^CNX𐶐鐶w肵܂Bw̏ꍇɂ `̒lɐ܂B
     */
    private String fRuntimepackage;

    /**
     * tB[h [verbose]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * verbose[hœ삳邩ǂB
     *
     * @param argVerbose tB[h[verbose]Ɋi[l
     */
    public void setVerbose(final String argVerbose) {
        fVerbose = argVerbose;
    }

    /**
     * tB[h[verbose]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * verbose[hœ삳邩ǂB
     *
     * @return tB[h[verbose]Ɋi[Ăl
     */
    public String getVerbose() {
        return fVerbose;
    }

    /**
     * tB[h [metadir]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ^fBNgBxlst@C̊i[܂ xmlt@C̊i[w肵܂B
     *
     * @param argMetadir tB[h[metadir]Ɋi[l
     */
    public void setMetadir(final String argMetadir) {
        fMetadir = argMetadir;
    }

    /**
     * tB[h[metadir]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ^fBNgBxlst@C̊i[܂ xmlt@C̊i[w肵܂B
     *
     * @return tB[h[metadir]Ɋi[Ăl
     */
    public String getMetadir() {
        return fMetadir;
    }

    /**
     * tB[h [targetdir]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * o͐tH_w肵܂Bw̏ꍇɂ̓Jgblancop܂B
     *
     * @param argTargetdir tB[h[targetdir]Ɋi[l
     */
    public void setTargetdir(final String argTargetdir) {
        fTargetdir = argTargetdir;
    }

    /**
     * tB[h[targetdir]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * o͐tH_w肵܂Bw̏ꍇɂ̓Jgblancop܂B
     *
     * @return tB[h[targetdir]Ɋi[Ăl
     */
    public String getTargetdir() {
        return fTargetdir;
    }

    /**
     * tB[h [tmpdir]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * e|fBNgw肵܂Bw̏ꍇɂ̓Jgtmpp܂B
     *
     * @param argTmpdir tB[h[tmpdir]Ɋi[l
     */
    public void setTmpdir(final String argTmpdir) {
        fTmpdir = argTmpdir;
    }

    /**
     * tB[h[tmpdir]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * e|fBNgw肵܂Bw̏ꍇɂ̓Jgtmpp܂B
     *
     * @return tB[h[tmpdir]Ɋi[Ăl
     */
    public String getTmpdir() {
        return fTmpdir;
    }

    /**
     * tB[h [targetlang]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ^[QbgƂȂvO~OꏈnBjava, cs, jsI\
     *
     * @param argTargetlang tB[h[targetlang]Ɋi[l
     */
    public void setTargetlang(final String argTargetlang) {
        fTargetlang = argTargetlang;
    }

    /**
     * tB[h[targetlang]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ^[QbgƂȂvO~OꏈnBjava, cs, jsI\
     *
     * @return tB[h[targetlang]Ɋi[Ăl
     */
    public String getTargetlang() {
        return fTargetlang;
    }

    /**
     * tB[h [runtimepackage]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ^CNX𐶐鐶w肵܂Bw̏ꍇɂ `̒lɐ܂B
     *
     * @param argRuntimepackage tB[h[runtimepackage]Ɋi[l
     */
    public void setRuntimepackage(final String argRuntimepackage) {
        fRuntimepackage = argRuntimepackage;
    }

    /**
     * tB[h[runtimepackage]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ^CNX𐶐鐶w肵܂Bw̏ꍇɂ `̒lɐ܂B
     *
     * @return tB[h[runtimepackage]Ɋi[Ăl
     */
    public String getRuntimepackage() {
        return fRuntimepackage;
    }

    /**
     * ̃o[IuWFNg̕\擾܂B
     *
     * IuWFNg̃V[͈͂łtoStringȂ_ɒӂėpĂB
     *
     * @return o[IuWFNg̕\B
     */
    public String toString() {
        final StringBuffer buf = new StringBuffer();
        buf.append("blanco.batchprocess.task.valueobject.BlancoBatchProcessBatchProcessInput[");
        buf.append("verbose=" + fVerbose);
        buf.append(",metadir=" + fMetadir);
        buf.append(",targetdir=" + fTargetdir);
        buf.append(",tmpdir=" + fTmpdir);
        buf.append(",targetlang=" + fTargetlang);
        buf.append(",runtimepackage=" + fRuntimepackage);
        buf.append("]");
        return buf.toString();
    }
}

==> blancoBatchProcess-0.2.0-src.zip: blancoBatchProcess/blanco/main/blanco/batchprocess/task/valueobject/BlancoBatchProcessBatchProcessInput.java <==
/*
 * ̃\[XR[h blanco FrameworkɂĎĂ܂B
 * ̃NXblancoValueObjectɂ莩܂B
 */
package blanco.batchprocess.task.valueobject;

/**
 * ob`NX [BlancoBatchProcessBatchProcess]̓̓o[IuWFNgNXłB BlancoResourceBundleAntTaskłB
 */
public class BlancoBatchProcessBatchProcessInput {
    /**
     * tB[h [verbose]
     *
     * ڂ̌^ [boolean]<br>
     * Kl   [false]<br>
     * verbose[hœ삳邩ǂB
     */
    private boolean fVerbose = false;

    /**
     * tB[h [metadir]
     *
     * ڂ̌^ [java.lang.String]<br>
     * ^fBNgBxlst@C̊i[܂ xmlt@C̊i[w肵܂B
     */
    private String fMetadir;

    /**
     * tB[h [targetdir]
     *
     * ڂ̌^ [java.lang.String]<br>
     * Kl   [blanco]<br>
     * o͐tH_w肵܂Bw̏ꍇɂ̓Jgblancop܂B
     */
    private String fTargetdir = "blanco";

    /**
     * tB[h [tmpdir]
     *
     * ڂ̌^ [java.lang.String]<br>
     * Kl   [tmp]<br>
     * e|fBNgw肵܂Bw̏ꍇɂ̓Jgtmpp܂B
     */
    private String fTmpdir = "tmp";

    /**
     * tB[h [targetlang]
     *
     * ڂ̌^ [java.lang.String]<br>
     * Kl   [java]<br>
     * ^[QbgƂȂvO~OꏈnBjava, cs, jsI\
     */
    private String fTargetlang = "java";

    /**
     * tB[h [runtimepackage]
     *
     * ڂ̌^ [java.lang.String]<br>
     * ^CNX𐶐鐶w肵܂Bw̏ꍇɂ `̒lɐ܂B
     */
    private String fRuntimepackage;

    /**
     * tB[h [verbose]̃Zb^[\bh
     *
     * ڂ̌^ [boolean]<br>
     * verbose[hœ삳邩ǂB
     *
     * @param argVerbose tB[h[verbose]Ɋi[l
     */
    public void setVerbose(final boolean argVerbose) {
        fVerbose = argVerbose;
    }

    /**
     * tB[h[verbose]̃Qb^[\bh
     *
     * ڂ̌^ [boolean]<br>
     * Kl   [false]<br>
     * verbose[hœ삳邩ǂB
     *
     * @return tB[h[verbose]Ɋi[Ăl
     */
    public boolean getVerbose() {
        return fVerbose;
    }

    /**
     * tB[h [metadir]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ^fBNgBxlst@C̊i[܂ xmlt@C̊i[w肵܂B
     *
     * @param argMetadir tB[h[metadir]Ɋi[l
     */
    public void setMetadir(final String argMetadir) {
        fMetadir = argMetadir;
    }

    /**
     * tB[h[metadir]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ^fBNgBxlst@C̊i[܂ xmlt@C̊i[w肵܂B
     *
     * @return tB[h[metadir]Ɋi[Ăl
     */
    public String getMetadir() {
        return fMetadir;
    }

    /**
     * tB[h [targetdir]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * o͐tH_w肵܂Bw̏ꍇɂ̓Jgblancop܂B
     *
     * @param argTargetdir tB[h[targetdir]Ɋi[l
     */
    public void setTargetdir(final String argTargetdir) {
        fTargetdir = argTargetdir;
    }

    /**
     * tB[h[targetdir]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * Kl   [blanco]<br>
     * o͐tH_w肵܂Bw̏ꍇɂ̓Jgblancop܂B
     *
     * @return tB[h[targetdir]Ɋi[Ăl
     */
    public String getTargetdir() {
        return fTargetdir;
    }

    /**
     * tB[h [tmpdir]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * e|fBNgw肵܂Bw̏ꍇɂ̓Jgtmpp܂B
     *
     * @param argTmpdir tB[h[tmpdir]Ɋi[l
     */
    public void setTmpdir(final String argTmpdir) {
        fTmpdir = argTmpdir;
    }

    /**
     * tB[h[tmpdir]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * Kl   [tmp]<br>
     * e|fBNgw肵܂Bw̏ꍇɂ̓Jgtmpp܂B
     *
     * @return tB[h[tmpdir]Ɋi[Ăl
     */
    public String getTmpdir() {
        return fTmpdir;
    }

    /**
     * tB[h [targetlang]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ^[QbgƂȂvO~OꏈnBjava, cs, jsI\
     *
     * @param argTargetlang tB[h[targetlang]Ɋi[l
     */
    public void setTargetlang(final String argTargetlang) {
        fTargetlang = argTargetlang;
    }

    /**
     * tB[h[targetlang]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * Kl   [java]<br>
     * ^[QbgƂȂvO~OꏈnBjava, cs, jsI\
     *
     * @return tB[h[targetlang]Ɋi[Ăl
     */
    public String getTargetlang() {
        return fTargetlang;
    }

    /**
     * tB[h [runtimepackage]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ^CNX𐶐鐶w肵܂Bw̏ꍇɂ `̒lɐ܂B
     *
     * @param argRuntimepackage tB[h[runtimepackage]Ɋi[l
     */
    public void setRuntimepackage(final String argRuntimepackage) {
        fRuntimepackage = argRuntimepackage;
    }

    /**
     * tB[h[runtimepackage]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ^CNX𐶐鐶w肵܂Bw̏ꍇɂ `̒lɐ܂B
     *
     * @return tB[h[runtimepackage]Ɋi[Ăl
     */
    public String getRuntimepackage() {
        return fRuntimepackage;
    }

    /**
     * ̃o[IuWFNg̕\擾܂B
     *
     * IuWFNg̃V[͈͂łtoStringȂ_ɒӂėpĂB
     *
     * @return o[IuWFNg̕\B
     */
    public String toString() {
        final StringBuffer buf = new StringBuffer();
        buf.append("blanco.batchprocess.task.valueobject.BlancoBatchProcessBatchProcessInput[");
        buf.append("verbose=" + fVerbose);
        buf.append(",metadir=" + fMetadir);
        buf.append(",targetdir=" + fTargetdir);
        buf.append(",tmpdir=" + fTmpdir);
        buf.append(",targetlang=" + fTargetlang);
        buf.append(",runtimepackage=" + fRuntimepackage);
        buf.append("]");
        return buf.toString();
    }
}
